public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] Documentation / sample code fixes for tracepoints
@ 2009-03-24 20:00 Jody McIntyre
  2009-03-24 20:18 ` Mathieu Desnoyers
                   ` (2 more replies)
  0 siblings, 3 replies; 5+ messages in thread
From: Jody McIntyre @ 2009-03-24 20:00 UTC (permalink / raw)
  To: torvalds; +Cc: linux-kernel, Mathieu Desnoyers

Fix the tracepoint documentation to refer to "tracepoint-sample" instead of
"tracepoint-example" to match what actually exists; fix the directory,
and clarify how to compile.

Change every instance of "example" in the sample tracepoint code to "sample"
for consistency.

Signed-off-by: Jody McIntyre <scjody@sun.com>

Index: linux-2.6/Documentation/tracepoints.txt
===================================================================
--- linux-2.6.orig/Documentation/tracepoints.txt
+++ linux-2.6/Documentation/tracepoints.txt
@@ -103,13 +103,14 @@ used to export the defined tracepoints.
 
 * Probe / tracepoint example
 
-See the example provided in samples/tracepoints/src
+See the example provided in samples/tracepoints
 
-Compile them with your kernel.
+Compile them with your kernel.  They are built during 'make' (not
+'make modules') when CONFIG_SAMPLE_TRACEPOINTS=m.
 
 Run, as root :
-modprobe tracepoint-example (insmod order is not important)
-modprobe tracepoint-probe-example
-cat /proc/tracepoint-example (returns an expected error)
-rmmod tracepoint-example tracepoint-probe-example
+modprobe tracepoint-sample (insmod order is not important)
+modprobe tracepoint-probe-sample
+cat /proc/tracepoint-sample (returns an expected error)
+rmmod tracepoint-sample tracepoint-probe-sample
 dmesg
Index: linux-2.6/samples/tracepoints/tracepoint-sample.c
===================================================================
--- linux-2.6.orig/samples/tracepoints/tracepoint-sample.c
+++ linux-2.6/samples/tracepoints/tracepoint-sample.c
@@ -1,6 +1,6 @@
 /* tracepoint-sample.c
  *
  * Executes a tracepoint when /proc/tracepoint-example is opened.
  *
  * (C) Copyright 2007 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
  *
@@ -16,7 +16,7 @@
 DEFINE_TRACE(subsys_event);
 DEFINE_TRACE(subsys_eventb);
 
-struct proc_dir_entry *pentry_example;
+struct proc_dir_entry *pentry_sample;
 
 static int my_open(struct inode *inode, struct file *file)
 {
@@ -32,25 +32,25 @@ static struct file_operations mark_ops =
 	.open = my_open,
 };
 
-static int __init example_init(void)
+static int __init sample_init(void)
 {
-	printk(KERN_ALERT "example init\n");
-	pentry_example = proc_create("tracepoint-example", 0444, NULL,
+	printk(KERN_ALERT "sample init\n");
+	pentry_sample = proc_create("tracepoint-sample", 0444, NULL,
 		&mark_ops);
-	if (!pentry_example)
+	if (!pentry_sample)
 		return -EPERM;
 	return 0;
 }
 
-static void __exit example_exit(void)
+static void __exit sample_exit(void)
 {
-	printk(KERN_ALERT "example exit\n");
-	remove_proc_entry("tracepoint-example", NULL);
+	printk(KERN_ALERT "sample exit\n");
+	remove_proc_entry("tracepoint-sample", NULL);
 }
 
-module_init(example_init)
-module_exit(example_exit)
+module_init(sample_init)
+module_exit(sample_exit)
 
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Mathieu Desnoyers");
-MODULE_DESCRIPTION("Tracepoint example");
+MODULE_DESCRIPTION("Tracepoint sample");

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2009-03-25 12:21 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -1,6 +1,6 @@
 /* tracepoint-sample.c
  *
- * Executes a tracepoint when /proc/tracepoint-example is opened.
+ * Executes a tracepoint when /proc/tracepoint-sample is opened.
  *
  * (C) Copyright 2007 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
2009-03-24 20:00 [PATCH] Documentation / sample code fixes for tracepoints Jody McIntyre
2009-03-24 20:18 ` Mathieu Desnoyers
2009-03-24 21:32 ` Ingo Molnar
2009-03-25 12:25   ` Jody McIntyre
2009-03-24 21:33 ` [tip:tracing/docs] tracing: " Jody McIntyre

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox